@@ -119,7 +119,8 @@ void NotesAgent::showConfigureDialog(qlonglong windowId)
 {
     QPointer<NotesAgentSettingsDialog> dialog = new NotesAgentSettingsDialog;
     if (windowId) {
-        KWindowSystem::setMainWindow(dialog, windowId);
+        dialog->setAttribute(Qt::WA_NativeWindow, true);
+        KWindowSystem::setMainWindow(dialog->windowHandle(), windowId);
     }
     if (dialog->exec()) {
         mNotesManager->load();
