@@ -39,11 +39,9 @@
 #include <KMime/KMimeMessage>
 
 #include <KNotification>
-#include <KIconLoader>
 #include <KLocalizedString>
 
 #include <QDateTime>
-#include <QIcon>
 #include <QTcpServer>
 #include <QTimer>
 
@@ -137,14 +135,14 @@ void NotesManager::slotCheckAlarm()
 {
     QDateTime from = NoteShared::NoteSharedGlobalConfig::self()->alarmsLastChecked().addSecs(1);
     if (!from.isValid()) {
-        from.setTime_t(0);
+        from.setSecsSinceEpoch(0);
     }
 
     const QDateTime now = QDateTime::currentDateTime();
     NoteShared::NoteSharedGlobalConfig::self()->setAlarmsLastChecked(now);
 
     Akonadi::Item::List lst;
-    Q_FOREACH (const Akonadi::Item &item, mListItem) {
+    for (const Akonadi::Item &item : qAsConst(mListItem)) {
         const NoteShared::NoteAlarmAttribute *attrAlarm = item.attribute<NoteShared::NoteAlarmAttribute>();
         if (attrAlarm) {
             if (attrAlarm->dateTime() < QDateTime::currentDateTime()) {
