@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -79,7 +79,7 @@ KNoteFindWidget::KNoteFindWidget(QWidget *parent)
     : QWidget(parent)
 {
     QVBoxLayout *vbox = new QVBoxLayout(this);
-    vbox->setMargin(0);
+    vbox->setContentsMargins(0, 0, 0, 0);
     QHBoxLayout *hbox = new QHBoxLayout;
     vbox->addLayout(hbox);
     QLabel *lab = new QLabel(i18nc("@label:textbox", "Search notes:"), this);
