@@ -45,7 +45,7 @@
 
 #include <KActionCollection>
 #include <KComboBox>
-#include <KFileDialog>
+#include <KFileCustomDialog>
 #include <KIconEffect>
 #include <KIconLoader>
 #include <KLocalizedString>
@@ -53,7 +53,6 @@
 #include <KToggleAction>
 #include <KToolBar>
 #include <KWindowSystem>
-#include <KWindowSystem/NETWM>
 #include <KXMLGUIBuilder>
 #include <KXMLGUIFactory>
 
@@ -68,10 +67,10 @@
 #include <QSizeGrip>
 #include <QVBoxLayout>
 #include <QTextEdit>
+#include <KWindowSystem/NETWM>
 
 #if KDEPIM_HAVE_X11
 #include <fixx11h.h>
-#include <QX11Info>
 #endif
 
 //#define DEBUG_SAVE_NOTE 1
@@ -512,15 +511,17 @@ void KNote::slotSaveAs()
         convert->setText(i18n("Save note as plain text"));
     }
     QUrl url;
-    QPointer<KFileDialog> dlg = new KFileDialog(url, QString(), this, convert);
-    dlg->setOperationMode(KFileDialog::Saving);
+    QPointer<KFileCustomDialog> dlg = new KFileCustomDialog(this);
+    dlg->setCustomWidget(convert);
+    dlg->setUrl(url);
+    dlg->setOperationMode(KFileWidget::Saving);
     dlg->setWindowTitle(i18n("Save As"));
     if (!dlg->exec()) {
         delete dlg;
         return;
     }
 
-    const QString fileName = dlg->selectedFile();
+    const QString fileName = dlg->fileWidget()->selectedFile();
     const bool htmlFormatAndSaveAsHtml = (convert && !convert->isChecked());
     delete dlg;
     if (fileName.isEmpty()) {
@@ -742,7 +743,7 @@ void KNote::createActions()
 #if KDEPIM_HAVE_X11
     m_toDesktop = new KSelectAction(i18n("To Desktop"), this);
     actionCollection()->addAction(QStringLiteral("to_desktop"), m_toDesktop);
-    connect(m_toDesktop, QOverload<QAction *>::of(&KSelectAction::triggered),
+    connect(m_toDesktop, qOverload<QAction *>(&KSelectAction::triggered),
             this, &KNote::slotPopupActionToDesktop);
     connect(m_toDesktop->menu(), &QMenu::aboutToShow,
             this, &KNote::slotUpdateDesktopActions);
@@ -756,7 +757,8 @@ void KNote::createActions()
     actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::SHIFT + Qt::Key_Backtab));
 
     actionCollection()->addAssociatedWidget(this);
-    foreach (QAction *action, actionCollection()->actions()) {
+    const auto lst = actionCollection()->actions();
+    for (QAction *action : lst) {
         action->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     }
     if (mAllowDebugAkonadiSearch) {
@@ -841,7 +843,8 @@ void KNote::createNoteFooter()
 
     // if there was just a way of making KComboBox adhere the toolbar height...
     if (m_tool) {
-        foreach (KComboBox *combo, m_tool->findChildren<KComboBox *>()) {
+        const auto comboboxs = m_tool->findChildren<KComboBox *>();
+        for (KComboBox *combo : comboboxs) {
             QFont font = combo->font();
             font.setPointSize(7);
             combo->setFont(font);
