@@ -50,7 +50,7 @@ class KNote : public QFrame, virtual public KXMLGUIClient, public KNoteInterface
     Q_OBJECT
 public:
     explicit KNote(const QDomDocument &buildDoc, const Akonadi::Item &item, bool allowAkonadiSearchDebug = false, QWidget *parent = nullptr);
-    ~KNote();
+    ~KNote() override;
 
     void setChangeItem(const Akonadi::Item &item, const QSet<QByteArray> &set = QSet<QByteArray>());
     void saveNote(bool force = false, bool sync = false);
